@@ -409,7 +409,8 @@ class C2dplot:
     #
     def fullProcess(self,uns,out="",component=None,xrange=20.,sigma=6.0,mergers="",cmap="jet",
                     cpt=0,noxz=False,contour=False,nc=20,center_cod=None,nopart=False,
-                    rect_sim=None, rect_comp="stars-stars",rect_dir="rectify2",rect_suffix="ev"):
+                    rect_sim=None, rect_comp="stars-stars",rect_dir="rectify2",rect_suffix="ev",
+                    circle=""):
         t0=time.clock()
         sigma_ori=sigma
         xrange_ori=xrange
@@ -418,6 +419,7 @@ class C2dplot:
         self.__rect_comp   = rect_comp
         self.__rect_dir    = rect_dir
         self.__rect_suffix = rect_suffix
+        self.__circle = circle
         self.__x={}
         # set color map
         comp_cmap=self.__setCmapComponents(cmap)
@@ -750,7 +752,17 @@ class C2dplot:
 
         img=ax.imshow(zd , origin='lower',cmap=cmap, norm = matplotlib.colors.LogNorm(),extent=[view_xmin, view_xmax, view_ymin, view_ymax])
 
-
+        if self.__circle!="" :
+            for prop in self.__circle.split(","):
+                radius=prop.split("%")
+                lstyle="solid" 
+                color="red"
+                if len(radius) > 1:
+                    color=radius[1].split("#")
+                    if len(color) > 1:
+                        lstyle=color[1]
+                cc=plt.Circle((0.,0.),float(radius[0]),color=str(color[0]),linestyle=lstyle,fill=False)
+                ax.add_artist(cc)
         #cax=fig.add_axes(np.linspace(np.log(zd.min()),np.log(zd.max()),4))
 
         #fig.colorbar(img,orientation='vertical',shrink=0.8,ticks=[np.linspace(1,zd.max(),15)])
@@ -775,6 +787,44 @@ class C2dplot:
         #plt.contour(zd, origin='lower',cmap='winter',norm = matplotlib.colors.LogNorm(), extent=[view_xmin, view_xmax, view_ymin, view_ymax])
         #plt.contour(zd,norm = matplotlib.colors.LogNorm(), extent=[view_xmin, view_xmax, view_ymin, view_ymax])
 
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#
+def commandLinePbm2():
+    dbname = None
+    import argparse
+    # help
+    parser = argparse.ArgumentParser(description="Build simulation movie after smart analysis",
+                                    formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+    # options
+
+    parser.add_argument('simname', help='Simulation name')
+
+    parser.add_argument('--dbname',help='UNS database file name', default=dbname)
+    parser.add_argument('--verbose',help='verbose mode on', dest="verbose", action="store_true", default=False)
+    parser.add_argument('--overwrite',help='overwrite file if exist', dest="overwrite", action="store_true", default=False)
+    parser.add_argument('--ncores', help='#cores used, 0 means all',default=4,type=int)
+    #parser.add_argument('--no-verbose',help='verbose mode off', dest="verbose", action="store_false", default=True)
+
+    # parse
+    args = parser.parse_args()
+
+    # start main funciton
+    processPbm2(args)
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#
+def processPbm2(args):
+    import unsiotools.simulations.c2dplot as c2d
+    movie = c2d.C2dplot(verbose_debug=args.verbose)
+    try:
+        movie.buildMovie(args.simname,overwrite=args.overwrite,ncores=args.ncores)
+    except Exception as x :
+        import traceback
+        print (x,file=sys.stderr)
+        traceback.print_exc(file=sys.stdout)
+    except KeyboardInterrupt:
+        sys.exit()
+
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # commandLine, parse the command line
 def commandLine():
@@ -791,7 +841,8 @@ def commandLine():
                         Syntax is \"component1:cmap1,component2:cmap2\"\
                         example: stars:rainbow,halo:Purples\n \
                         (to display all colormap available use \"show\" as keyword)",
-                        default="gas:jet,stars:rainbow,halo:PuOr")
+                        default="gas:jet,stars:Paired,halo:Accent")
+                        #other cmap="gas:jet,stars:rainbow,halo:PuOr"
     parser.add_argument('--mergers', help="use results from mergers analysis to re-center (ex; @mdf648) to get file automatically from simulation ",default="",type=str)
     parser.add_argument('--cod', help="use COD file to re-center, or @sim (ex; @mdf648) to get file automatically from simulation ",default=None)
     parser.add_argument('--rect_sim', help="give a simname or a rectify file name to activate rectify",default=None)
@@ -802,6 +853,8 @@ def commandLine():
     parser.add_argument('--noxz',help='no XZ projection',dest="noxz", action="store_true", default=False)
     parser.add_argument('--nopart',help='not display particles number',dest="nopart", action="store_true", default=False)
     parser.add_argument('--contour',help='toggle iso contour display',dest="contour", action="store_true", default=False)
+    parser.add_argument('--circle',help='Draw circles with given radius{%%color#linestyle}[,radius1,radius2] centered in 0,0,0.'
+                                        'Eg. 1.5%%red#dashed,2.6%%yellow#dotted, use real name for color, like red,yellow etc.., possible linestyle={solid,dashed,dashdot,dotted} ',dest="circle", default="", type=str)
     parser.add_argument('--nc',help='#levels contour',default=20,type=int)
     parser.add_argument('--cpt', help="index of the image (out.cpt.jpg)",default=0,type=int)
     parser.add_argument('--verbose',help='verbose mode',dest="verbose", action="store_true", default=False)
@@ -840,7 +893,7 @@ def process(args):
             c.fullProcess(uns=uns,out=args.out,component=args.component,xrange=float(args.range),sigma=args.sigma,
                           mergers=args.mergers,cmap=args.cmap,cpt=cpt,noxz=args.noxz, contour=args.contour,
                           nc=args.nc,center_cod=args.cod,nopart=args.nopart,
-                          rect_sim=args.rect_sim,rect_comp=args.rect_comp,rect_dir=args.rect_dir,rect_suffix=args.rect_suffix)
+                          rect_sim=args.rect_sim,rect_comp=args.rect_comp,rect_dir=args.rect_dir,rect_suffix=args.rect_suffix, circle=args.circle)
             cpt =cpt+1
 #        else:
 #            print ("[%s] is not a UNS snapshot ..."%(simname))
